@@ -7,6 +7,7 @@ from multiprocessing.connection import Connection
 from pickle import UnpicklingError
 
 import numpy as np
+from urh.util.Formatter import Formatter
 
 from urh import settings
 from urh.dev.native.SendConfig import SendConfig
@@ -38,6 +39,7 @@ class Device(object):
         SET_FREQUENCY_CORRECTION = 8
         SET_CHANNEL_INDEX = 9
         SET_ANTENNA_INDEX = 10
+        SET_BIAS_TEE_ENABLED = 11
 
     ASYNCHRONOUS = False
 
@@ -88,6 +90,8 @@ class Device(object):
                     pass
 
                 ret = getattr(cls.DEVICE_LIB, method_name)(value)
+                if isinstance(value, int) or isinstance(value, float):
+                    value = Formatter.big_value_with_suffix(value)
                 ctrl_connection.send("{0} to {1}:{2}".format(tag, value, ret))
             except AttributeError as e:
                 logger.warning(str(e))
@@ -247,6 +251,7 @@ class Device(object):
         self.__antenna_index = 0
 
         self.__freq_correction = 0
+        self.__bias_tee_enabled = False
         self.__direct_sampling_mode = 0
         self.bandwidth_is_adjustable = True
 
@@ -520,6 +525,23 @@ class Device(object):
         except (BrokenPipeError, OSError):
             pass
 
+    @property
+    def bias_tee_enabled(self):
+        return self.__bias_tee_enabled
+
+    @bias_tee_enabled.setter
+    def bias_tee_enabled(self, value: bool):
+        value = bool(value)
+        if value != self.__bias_tee_enabled:
+            self.__bias_tee_enabled = value
+            self.set_device_bias_tee_enabled(value)
+
+    def set_device_bias_tee_enabled(self, value):
+        try:
+            self.parent_ctrl_conn.send((self.Command.SET_BIAS_TEE_ENABLED.name, int(value)))
+        except (BrokenPipeError, OSError):
+            pass
+
     @property
     def freq_correction(self):
         return self.__freq_correction
